==> ZenTaoPMS.biz7.7.php5.4_5.6.zip: zentaopms/extension/max/feedback/lang/fr.php <==
<?php
global $config;
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->allModule         = 'All Module';
$lang->feedback->manageCate        = 'Manage Module';
$lang->feedback->index             = 'Accueil Feedback';
$lang->feedback->create            = 'Ajout Feedback';
$lang->feedback->edit              = 'Editer Feedback';
$lang->feedback->editOthers        = 'Edit Other Feedback';
$lang->feedback->createFaq         = 'Ajout FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Interface Feedback';
$lang->feedback->browse            = 'Liste Feedback';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'D?tail Feedback';
$lang->feedback->review            = 'Examen';
$lang->feedback->reviewAction      = 'Examiner Feedback';
$lang->feedback->adminView         = 'Interface D?veloppement';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Fermer';
$lang->feedback->closeAction       = 'Fermer Feedback';
$lang->feedback->feelLike          = " J'aime!";
$lang->feedback->ask               = 'Doute';
$lang->feedback->toStory           = 'vers ' . $lang->SRCommon;
$lang->feedback->toUserStory       = 'vers ' . $lang->URCommon;
$lang->feedback->toTask            = 'vers T?che';
$lang->feedback->toBug             = 'vers Bug';
$lang->feedback->toTodo            = 'vers Agenda';
$lang->feedback->toTicket          = 'To Ticket';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->userStory         = $lang->URCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Agenda';
$lang->feedback->task              = 'T?che';
$lang->feedback->ticket            = 'Ticket';
$lang->feedback->reply             = 'R?pondre';
$lang->feedback->replyAction       = 'R?pondre au Feedback';
$lang->feedback->convert           = 'Convertir';
$lang->feedback->assign            = 'Assigner';
$lang->feedback->assignAction      = 'Assigner Feedback';
$lang->feedback->export            = 'Exporter';
$lang->feedback->exportAction      = 'Exporter Feedback';
$lang->feedback->assignTo          = 'Assign';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Supprimer Feedback';
$lang->feedback->mailNotify        = 'Notification par mail';
$lang->feedback->search            = 'Recherche';
$lang->feedback->comment           = 'Commenter';
$lang->feedback->products          = 'Privil?ge';
$lang->feedback->batchEdit         = 'Editer par lot';
$lang->feedback->batchClose        = 'Fermer par lot';
$lang->feedback->batchReview       = 'Examen par lot';
$lang->feedback->batchAssignTo     = 'Assigner par lot';
$lang->feedback->batchChangeModule = 'R?affecter Modules par lot';
$lang->feedback->manageProduct     = 'G?rer les Privil?ges Utilisateur';
$lang->feedback->consumed          = 'Coût Total';
$lang->feedback->noFeedback        = 'No feedback for the time being.';
$lang->feedback->import            = 'Import';
$lang->feedback->exportTemplate    = 'Export Template';
$lang->feedback->exportData        = 'Export Data';
$lang->feedback->pri               = 'Pri';
$lang->feedback->source            = 'Source company';
$lang->feedback->sourceInfo        = 'Feedback source';
$lang->feedback->internalContact   = 'Internal contact';
$lang->feedback->company           = 'Feedback company';
$lang->feedback->email             = 'Feedback email';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Titre';
$lang->feedback->storyTitle     = $lang->SRCommon;
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Statut';
$lang->feedback->subStatus      = 'Sous-Statut';
$lang->feedback->openedBy       = 'Ajout? par';
$lang->feedback->openedDate     = 'Ajout? le';
$lang->feedback->processedBy    = 'R?pondu par';
$lang->feedback->processedDate  = 'R?pondu le';
$lang->feedback->reviewedBy     = 'Examin? par';
$lang->feedback->reviewedDate   = 'Examin? le';
$lang->feedback->reviewResult   = 'Verdict';
$lang->feedback->reviewedByAB   = 'Examinateur';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Verdict';
$lang->feedback->assignedTo     = 'Assign';
$lang->feedback->assignedDate   = 'Date Assign.';
$lang->feedback->closedBy       = 'Ferm? par';
$lang->feedback->closedDate     = 'Date Fermeture';
$lang->feedback->closedReason   = 'Raison Fermeture';
$lang->feedback->public         = 'Public';
$lang->feedback->publicAB       = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'R?sultat';
$lang->feedback->files          = 'Fichiers';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Compartiment';
$lang->feedback->editedBy       = 'Modifi? par';
$lang->feedback->editedDate     = 'Dern.Modif';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Non assign';
$lang->feedback->deptManager    = 'Responsable';
$lang->feedback->reviewOpinion  = 'Opinion examen';
$lang->feedback->deleted        = 'Supprim';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select sprint/stage';

$lang->feedback->lblBasic       = 'Info de Base';
$lang->feedback->lblTrace       = 'Diagramme de Tra?abilit';
$lang->feedback->assigntome     = "Me l'assigner";
$lang->feedback->allProduct     = 'Tout ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';
$lang->feedback->repeatFeedback = 'Repeat Feedback';

$lang->feedback->grantUser   = 'Utilisateur autoris';
$lang->feedback->noGrantUser = 'Utilisateur non autoris';
$lang->feedback->hasPrivUser = 'Les utilisateurs de Feedback ont les privil?ges de tous les produits par d?faut. Si un privil?ge est attribu?, ils auront les privil?ges du produit associ?.';

$lang->feedback->mergeModule    = 'Merge module';
$lang->feedback->mergeTip       = 'There are %d pieces of data to be merged this time, 50 pieces of data to be merged per page, and %d times to be merged.';
$lang->feedback->feedbackModule = 'Feedback module';
$lang->feedback->productModule  = 'Product module';
$lang->feedback->syncProduct    = 'Synchronize product modules';
$lang->feedback->syncProductTo  = 'Sync to product';
$lang->feedback->syncConfirm    = 'Whether to merge the existing module with the product module';
$lang->feedback->syncWarning    = 'After the product module is synchronized, it cannot be revoked. Please click Confirm carefully';

$lang->feedback->syncLeveList[1]  = 'One level module';
$lang->feedback->syncLeveList[2]  = 'Two level module';
$lang->feedback->syncLeveList[3]  = 'Three level module';
$lang->feedback->syncLeveList[4]  = 'Four level module';
$lang->feedback->syncLeveList[5]  = 'Five level module';

$lang->feedback->tabList['unclosed'] = 'Ouverts';
$lang->feedback->tabList['all']      = 'Tout';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
if($this->config->systemMode == 'new')
{
    $lang->feedback->typeList['issue']       = 'Issue';
    $lang->feedback->typeList['risk']        = 'Risk';
    $lang->feedback->typeList['opportunity'] = 'Opportunity';
}

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = '? clarifier';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Attente examen';
$lang->feedback->statusList['clarify']    = '? clarifier';
$lang->feedback->statusList['wait']       = 'En attente';
$lang->feedback->statusList['commenting'] = 'En cours';
$lang->feedback->statusList['replied']    = 'R?pondu';
$lang->feedback->statusList['asked']      = 'Incertain';
$lang->feedback->statusList['closed']     = 'Ferm';

$lang->feedback->closedReasonList['']          = '';
$lang->feedback->closedReasonList['commented'] = 'R?pondu';
$lang->feedback->closedReasonList['repeat']    = 'R?p?ter';
$lang->feedback->closedReasonList['refuse']    = 'Rejeter';

$lang->feedback->solutionList['']            = '';
$lang->feedback->solutionList['tobug']       = 'Convert to Bug';
$lang->feedback->solutionList['tostory']     = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['touserstory'] = 'Convert to ' . $lang->URCommon;
$lang->feedback->solutionList['totask']      = 'Convert to task';
$lang->feedback->solutionList['totodo']      = 'Convert to Todo';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Priv';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Voulez-vous supprimer ce feedback ?';
$lang->feedback->confirmClose  = 'Voulez-vous cl?turer ce feedback ?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented        = '$date, r?pondu par <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule         = "<div>Vous n'avez pas de cat?gories.</div>";
$lang->feedback->batchEditTip     = 'Feedback with ID %s is not created by the user and will be ignored automatically';
$lang->feedback->mustChooseResult = 'S?lect Verdict';

$lang->feedback->mustInputComment['replied']   = 'Reply content must be filled in';
$lang->feedback->mustInputComment['commented'] = 'Comment content must be filled in';
$lang->feedback->mustInputComment['asked']     = 'Ask content must be filled in';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, ferm? par <strong>$actor</strong>. Raison de fermeture est <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, examin? par <strong>$actor</strong>. Le verdict est <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featureBar['admin']['all']        = 'All';
$lang->feedback->featureBar['admin']['wait']       = 'Waiting';
$lang->feedback->featureBar['admin']['doing']      = 'Doing';
$lang->feedback->featureBar['admin']['toclosed']   = 'To Closed';
$lang->feedback->featureBar['admin']['review']     = 'Review';
$lang->feedback->featureBar['admin']['assigntome'] = 'AssignedToMe';
$lang->feedback->featureBar['admin']['openedbyme'] = 'FeedbackByMe';
$lang->feedback->featureBar['admin']['public']     = 'Public';

$lang->feedback->featureBar['admin']['more']['tostory']       = "Have to {$lang->SRCommon}";
$lang->feedback->featureBar['admin']['more']['torequirement'] = "Have to {$lang->URCommon}";
$lang->feedback->featureBar['admin']['more']['totask']        = 'Have to Task';
$lang->feedback->featureBar['admin']['more']['tobug']         = 'Have to Bug';
$lang->feedback->featureBar['admin']['more']['totodo']        = 'Have to Todo';
$lang->feedback->featureBar['admin']['more']['toticket']      = 'Have to Ticket';

$lang->feedback->notifyList['0'] = 'no';
$lang->feedback->notifyList['1'] = 'yes';

$lang->feedback->priList[0] = '';
$lang->feedback->priList[1] = '1';
$lang->feedback->priList[2] = '2';
$lang->feedback->priList[3] = '3';
$lang->feedback->priList[4] = '4';

==> ZenTaoPMS.biz8.0.php7.1.zip: zentaopms/extension/max/feedback/lang/fr.php <==
<?php
global $config;
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->allModule         = 'All Module';
$lang->feedback->manageCate        = 'Catégorie de gestion';
$lang->feedback->index             = 'Accueil Feedback';
$lang->feedback->create            = 'Ajout Feedback';
$lang->feedback->edit              = 'Editer Feedback';
$lang->feedback->editOthers        = 'Edit Other Feedback';
$lang->feedback->createFaq         = 'Ajout FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Interface Feedback';
$lang->feedback->browse            = 'Liste Feedback';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'D?tail Feedback';
$lang->feedback->review            = 'Examen';
$lang->feedback->reviewAction      = 'Examiner Feedback';
$lang->feedback->adminView         = 'Interface développeur';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Fermer';
$lang->feedback->closeAction       = 'Fermer Feedback';
$lang->feedback->feelLike          = " J'aime!";
$lang->feedback->ask               = 'Doute';
$lang->feedback->toStory           = 'vers ' . $lang->SRCommon;
$lang->feedback->toUserStory       = 'vers ' . $lang->URCommon;
$lang->feedback->toTask            = 'vers Mission';
$lang->feedback->toBug             = 'vers Bug';
$lang->feedback->toTodo            = 'vers Agenda';
$lang->feedback->toTicket          = 'To Ticket';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->userStory         = $lang->URCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Agenda';
$lang->feedback->task              = 'Mission';
$lang->feedback->reply             = 'Réponse';
$lang->feedback->ticket            = 'Ticket';
$lang->feedback->replyAction       = 'Réponse aux commentaires';
$lang->feedback->convert           = 'Convertir';
$lang->feedback->assign            = 'Assigner';
$lang->feedback->assignAction      = 'Assigner Feedback';
$lang->feedback->export            = 'Exporter';
$lang->feedback->exportAction      = 'Exporter Feedback';
$lang->feedback->assignTo          = 'Assign';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Supprimer Feedback';
$lang->feedback->activate          = 'Activate';
$lang->feedback->mailNotify        = 'Notification par mail';
$lang->feedback->search            = 'Recherche';
$lang->feedback->comment           = 'Commenter';
$lang->feedback->commentAB         = 'Remark';
$lang->feedback->products          = 'Setting';
$lang->feedback->batchEdit         = 'Editer par lot';
$lang->feedback->batchClose        = 'Fermer par lot';
$lang->feedback->batchReview       = 'Examen par lot';
$lang->feedback->batchAssignTo     = 'Assigner par lot';
$lang->feedback->batchChangeModule = 'Module de changement de lot';
$lang->feedback->manageProduct     = 'Gérer les droits des utilisateurs';
$lang->feedback->consumed          = 'Coût Total';
$lang->feedback->noFeedback        = 'No feedback for the time being.';
$lang->feedback->import            = 'Import';
$lang->feedback->exportTemplate    = 'Export Template';
$lang->feedback->exportData        = 'Export Data';
$lang->feedback->pri               = 'Pri';
$lang->feedback->source            = 'Source company';
$lang->feedback->sourceInfo        = 'Feedback source';
$lang->feedback->internalContact   = 'Internal contact';
$lang->feedback->company           = 'Feedback company';
$lang->feedback->email             = 'Feedback email';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Titre';
$lang->feedback->storyTitle     = $lang->SRCommon;
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Statut';
$lang->feedback->subStatus      = 'Sous-Statut';
$lang->feedback->openedBy       = 'créateur';
$lang->feedback->openedDate     = 'Create Date';
$lang->feedback->processedBy    = 'Répondants par';
$lang->feedback->processedDate  = 'Répondants le';
$lang->feedback->reviewedBy     = 'Vérifié par';
$lang->feedback->reviewedDate   = 'Vérifié le';
$lang->feedback->reviewResult   = 'Verdict';
$lang->feedback->reviewedByAB   = 'Examinateur';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Verdict';
$lang->feedback->assignedTo     = 'Assign';
$lang->feedback->assignedDate   = 'Date Assign.';
$lang->feedback->activatedBy    = 'activatedBy';
$lang->feedback->activatedDate  = 'activatedDate';
$lang->feedback->closedBy       = 'Fermé par';
$lang->feedback->closedDate     = 'Date Fermeture';
$lang->feedback->closedReason   = 'Raison Fermeture';
$lang->feedback->public         = 'Public';
$lang->feedback->publicAB       = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->notifyEmailAB  = 'Feedback Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'Conséquences';
$lang->feedback->files          = 'Fichiers';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Compartiment';
$lang->feedback->editedBy       = 'Modifié par';
$lang->feedback->editedDate     = 'Dern.Modif';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Non assign';
$lang->feedback->deptManager    = 'Responsable';
$lang->feedback->reviewOpinion  = 'Opinion examen';
$lang->feedback->deleted        = 'Supprim';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select sprint/stage';

$lang->feedback->lblBasic       = 'Info de Base';
$lang->feedback->lblTrace       = 'Diagramme de Tra?abilit';
$lang->feedback->assigntome     = "Me l'assigner";
$lang->feedback->allProduct     = 'Tout ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';
$lang->feedback->repeatFeedback = 'Repeat Feedback';

$lang->feedback->grantUser   = 'Utilisateur autoris';
$lang->feedback->noGrantUser = 'Utilisateur non autoris';
$lang->feedback->hasPrivUser = "Par défaut, l'utilisateur de rétroaction a la permission de tous les produits. Si des permissions sont attribuées, elles auront les permissions pour le produit concerné.";

$lang->feedback->mergeModule    = 'Merge module';
$lang->feedback->mergeTip       = 'There are %d pieces of data to be merged this time, 50 pieces of data to be merged per page, and %d times to be merged.';
$lang->feedback->closedFeedback = 'Feedback %s is closed and will not be closed.';
$lang->feedback->feedbackModule = 'Feedback module';
$lang->feedback->productModule  = 'Product module';
$lang->feedback->syncProduct    = 'Synchronize product modules';
$lang->feedback->syncProductTo  = 'Sync to product';
$lang->feedback->syncConfirm    = 'Whether to merge the existing module with the product module';
$lang->feedback->syncWarning    = 'After the product module is synchronized, it cannot be revoked. Please click Confirm carefully';

$lang->feedback->productSetting          = 'Product Setting';
$lang->feedback->head                    = 'Feedback Manager';
$lang->feedback->ticketHead              = 'Ticket Manager';
$lang->feedback->productSettingSaveError = 'At least one product has to be kept in the Product Setting for the feedback function to work properly.';

$lang->feedback->syncLeveList[1]  = 'One level module';
$lang->feedback->syncLeveList[2]  = 'Two level module';
$lang->feedback->syncLeveList[3]  = 'Three level module';
$lang->feedback->syncLeveList[4]  = 'Four level module';
$lang->feedback->syncLeveList[5]  = 'Five level module';

$lang->feedback->tabList['all']      = 'Tout';
$lang->feedback->tabList['unclosed'] = 'Ouverts';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
$lang->feedback->typeList['issue']       = 'Issue';
$lang->feedback->typeList['risk']        = 'Risk';
$lang->feedback->typeList['opportunity'] = 'Opportunity';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = 'À préciser';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Attente examen';
$lang->feedback->statusList['clarify']    = 'À préciser';
$lang->feedback->statusList['wait']       = 'En attente';
$lang->feedback->statusList['commenting'] = 'En cours';
$lang->feedback->statusList['replied']    = 'Répondez';
$lang->feedback->statusList['asked']      = 'Incertain';
$lang->feedback->statusList['closed']     = 'Ferm';

$lang->feedback->closedReasonList['']          = '';
$lang->feedback->closedReasonList['commented'] = 'Répondez';
$lang->feedback->closedReasonList['repeat']    = 'Je répète';
$lang->feedback->closedReasonList['refuse']    = 'Rejeter';

$lang->feedback->solutionList['']            = '';
$lang->feedback->solutionList['tobug']       = 'Convert to Bug';
$lang->feedback->solutionList['tostory']     = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['touserstory'] = 'Convert to ' . $lang->URCommon;
$lang->feedback->solutionList['totask']      = 'Convert to task';
$lang->feedback->solutionList['totodo']      = 'Convert to Todo';
$lang->feedback->solutionList['toticket']    = 'Convert to Ticket';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Priv';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Voulez-vous supprimer ce feedback ?';
$lang->feedback->confirmClose  = 'Voulez - vous mettre fin à cette rétroaction?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented            = '$date, répondez par <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule             = "<div>Vous n'avez pas de catégorie.</div>";
$lang->feedback->batchEditTip         = 'Feedback with ID %s is not created by the user and will be ignored automatically';
$lang->feedback->mustChooseResult     = 'Sélectionner les résultats';
$lang->feedback->ignoreClosedFeedback = "Feedback %s status is closed, and the operation has been filtered.";

$lang->feedback->mustInputComment['replied']   = 'Reply content must be filled in';
$lang->feedback->mustInputComment['commented'] = 'Comment content must be filled in';
$lang->feedback->mustInputComment['asked']     = 'Ask content must be filled in';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, fermé par <strong>$actor</strong>. Raison de fermeture est <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, vérifié par <strong>$actor</strong>. Le verdict est <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featureBar['admin']['all']        = 'All';
$lang->feedback->featureBar['admin']['wait']       = 'Waiting';
$lang->feedback->featureBar['admin']['doing']      = 'Doing';
$lang->feedback->featureBar['admin']['toclosed']   = 'To Closed';
$lang->feedback->featureBar['admin']['review']     = 'Review';
$lang->feedback->featureBar['admin']['assigntome'] = 'AssignedToMe';
$lang->feedback->featureBar['admin']['openedbyme'] = 'FeedbackByMe';
$lang->feedback->featureBar['admin']['public']     = 'Public';

$lang->feedback->featureBar['admin']['more']['tostory']       = "Have to {$lang->SRCommon}";
$lang->feedback->featureBar['admin']['more']['torequirement'] = "Have to {$lang->URCommon}";
$lang->feedback->featureBar['admin']['more']['totask']        = 'Have to Task';
$lang->feedback->featureBar['admin']['more']['tobug']         = 'Have to Bug';
$lang->feedback->featureBar['admin']['more']['totodo']        = 'Have to Todo';
$lang->feedback->featureBar['admin']['more']['toticket']      = 'Have to Ticket';

$lang->feedback->notifyList['']  = '';
$lang->feedback->notifyList['0'] = 'no';
$lang->feedback->notifyList['1'] = 'yes';

$lang->feedback->priList[0] = '';
$lang->feedback->priList[1] = '1';
$lang->feedback->priList[2] = '2';
$lang->feedback->priList[3] = '3';
$lang->feedback->priList[4] = '4';

$lang->feedback->productSettingNoProduct = 'No product can be set at present';
$lang->feedback->accessDenied            = 'You have no access to the feedback.';
